You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@commons.apache.org by br...@apache.org on 2014/03/12 20:25:51 UTC

svn commit: r1576865 - /commons/sandbox/beanutils2/trunk/src/main/java/org/apache/commons/beanutils2/PropertyInterpreter.java

Author: britter
Date: Wed Mar 12 19:25:51 2014
New Revision: 1576865

URL: http://svn.apache.org/r1576865
Log:
Rename propertyName to propertyExpression since we're not only dealing with simple property names here.

Modified:
    commons/sandbox/beanutils2/trunk/src/main/java/org/apache/commons/beanutils2/PropertyInterpreter.java

Modified: commons/sandbox/beanutils2/trunk/src/main/java/org/apache/commons/beanutils2/PropertyInterpreter.java
URL: http://svn.apache.org/viewvc/commons/sandbox/beanutils2/trunk/src/main/java/org/apache/commons/beanutils2/PropertyInterpreter.java?rev=1576865&r1=1576864&r2=1576865&view=diff
==============================================================================
--- commons/sandbox/beanutils2/trunk/src/main/java/org/apache/commons/beanutils2/PropertyInterpreter.java (original)
+++ commons/sandbox/beanutils2/trunk/src/main/java/org/apache/commons/beanutils2/PropertyInterpreter.java Wed Mar 12 19:25:51 2014
@@ -29,22 +29,22 @@ final class PropertyInterpreter
     /**
      * Interprets a given simple/indexed/mapped/nested property name or any combination of it.
      *
      * @param beanAccessor A {@link BeanAccessor} to resolve the given {@param propertyName}
      * @param propertyName A simple/indexed/mapped/nested property name or any combination of it
      * @return A {@link BeanAccessor} representing the resolved {@param propertyName}
      */
-    public static BeanAccessor<?> interpret( BeanAccessor<?> beanAccessor, String propertyName )
+    public static BeanAccessor<?> interpret( BeanAccessor<?> beanAccessor, String propertyExpression )
     {
-        Queue<Expression> expressionQueue = buildExpressionQueue( propertyName );
+        Queue<Expression> expressionQueue = buildExpressionQueue( propertyExpression );
 
         return processExpressions( beanAccessor, expressionQueue );
     }
 
-    private static Queue<Expression> buildExpressionQueue( String propertyName )
+    private static Queue<Expression> buildExpressionQueue( String propertyExpression )
     {
         Queue<Expression> expressionQueue = new LinkedList<Expression>();
 
-        String[] properties = obtainProperties( propertyName );
+        String[] properties = obtainProperties( propertyExpression );
 
         for ( String property : properties )
         {
@@ -63,7 +63,7 @@ final class PropertyInterpreter
             else
             {
                 throw new IllegalArgumentException(
-                    String.format( "The specified propertyName '%s' is not valid.", propertyName ) );
+                    String.format( "The specified propertyExpression '%s' is not valid.", propertyExpression ) );
             }
         }
 
@@ -81,9 +81,9 @@ final class PropertyInterpreter
         return beanAccessor;
     }
 
-    private static String[] obtainProperties( String propertyName )
+    private static String[] obtainProperties( String propertyExpression )
     {
-        String[] properties = propertyName.split( "\\." );
+        String[] properties = propertyExpression.split( "\\." );
 
         return properties;
     }
@@ -29,22 +29,22 @@ final class PropertyInterpreter
      * Interprets a given simple/indexed/mapped/nested property name or any combination of it.
      *
-     * @param beanAccessor A {@link BeanAccessor} to resolve the given {@param propertyName}
-     * @param propertyName A simple/indexed/mapped/nested property name or any combination of it
-     * @return A {@link BeanAccessor} representing the resolved {@param propertyName}
+     * @param beanAccessor A {@link BeanAccessor} to resolve the given {@param propertyExpression}
+     * @param propertyExpression A simple/indexed/mapped/nested property name or any combination of it
+     * @return A {@link BeanAccessor} representing the resolved {@param propertyExpression}
      */